"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/collapse-transition.tsx
var collapse_transition_exports = {};
__export(collapse_transition_exports, {
  CollapseTransition: () => CollapseTransition
});
module.exports = __toCommonJS(collapse_transition_exports);
var import_shared_utils = require("@nextui-org/shared-utils");
var import_framer_motion = require("framer-motion");
var import_react = require("react");

// src/transition-utils.ts
var TRANSITION_EASINGS = {
  ease: [0.25, 0.1, 0.25, 1],
  easeIn: [0.4, 0, 1, 1],
  easeOut: [0, 0, 0.2, 1],
  easeInOut: [0.4, 0, 0.2, 1],
  softSpring: [0.155, 1.105, 0.295, 1.12]
};
var TRANSITION_DEFAULTS = {
  enter: {
    duration: 0.2,
    ease: TRANSITION_EASINGS.easeOut
  },
  exit: {
    duration: 0.1,
    ease: TRANSITION_EASINGS.easeIn
  }
};
var withDelay = {
  enter: (transition, delay) => ({
    ...transition,
    delay: typeof delay === "number" ? delay : delay == null ? void 0 : delay["enter"]
  }),
  exit: (transition, delay) => ({
    ...transition,
    delay: typeof delay === "number" ? delay : delay == null ? void 0 : delay["exit"]
  })
};

// src/collapse-transition.tsx
var import_jsx_runtime = require("react/jsx-runtime");
var defaultTransitions = {
  exit: {
    height: {
      duration: 0.2,
      ease: TRANSITION_EASINGS.ease
    },
    opacity: {
      duration: 0.3,
      ease: TRANSITION_EASINGS.ease
    },
    y: {
      duration: 0.3,
      ease: TRANSITION_EASINGS.ease
    }
  },
  enter: {
    height: {
      duration: 0.6,
      ease: TRANSITION_EASINGS.softSpring
    },
    opacity: {
      duration: 0.8,
      ease: TRANSITION_EASINGS.ease
    },
    y: {
      duration: 0.6,
      ease: TRANSITION_EASINGS.ease
    }
  }
};
var variants = {
  enter: ({ animateOpacity, endingHeight, endingY, transition, transitionEnd, delay }) => {
    var _a;
    return {
      ...animateOpacity && { opacity: 1 },
      y: endingY,
      height: endingHeight,
      transitionEnd: transitionEnd == null ? void 0 : transitionEnd.enter,
      transition: (_a = transition == null ? void 0 : transition.enter) != null ? _a : withDelay.enter(defaultTransitions.enter, delay)
    };
  },
  exit: ({ animateOpacity, startingHeight, transition, startingY, transitionEnd, delay }) => {
    var _a;
    return {
      ...animateOpacity && { opacity: (0, import_shared_utils.isNumeric)(startingHeight) ? 1 : 0 },
      y: startingY,
      height: startingHeight,
      transitionEnd: transitionEnd == null ? void 0 : transitionEnd.exit,
      transition: (_a = transition == null ? void 0 : transition.exit) != null ? _a : withDelay.exit(defaultTransitions.exit, delay)
    };
  }
};
var CollapseTransition = (0, import_react.forwardRef)(
  (props, ref) => {
    const {
      in: isOpen,
      unmountOnExit,
      animateOpacity = true,
      startingHeight = 0,
      endingHeight = "auto",
      startingY = 10,
      endingY = 0,
      style,
      className,
      transition,
      transitionEnd,
      ...rest
    } = props;
    const [mounted, setMounted] = (0, import_react.useState)(false);
    (0, import_react.useEffect)(() => {
      const timeout = setTimeout(() => {
        setMounted(true);
      });
      return () => clearTimeout(timeout);
    }, []);
    if (Boolean(startingHeight > 0 && unmountOnExit)) {
      (0, import_shared_utils.warn)(
        `startingHeight and unmountOnExit are mutually exclusive. You can't use them together`,
        "FramerTransitions - Collapse"
      );
    }
    const hasStartingHeight = parseFloat(startingHeight.toString()) > 0;
    const custom = {
      startingHeight,
      endingHeight,
      startingY,
      endingY,
      animateOpacity,
      transition: !mounted ? { enter: { duration: 0 } } : transition,
      transitionEnd: {
        enter: transitionEnd == null ? void 0 : transitionEnd.enter,
        exit: unmountOnExit ? transitionEnd == null ? void 0 : transitionEnd.exit : {
          ...transitionEnd == null ? void 0 : transitionEnd.exit,
          display: hasStartingHeight ? "block" : "none"
        }
      }
    };
    const show = unmountOnExit ? isOpen : true;
    const animate = isOpen || unmountOnExit ? "enter" : "exit";
    return /* @__PURE__ */ (0, import_jsx_runtime.jsx)(import_framer_motion.AnimatePresence, { custom, initial: false, children: show && /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
      import_framer_motion.motion.div,
      {
        ref,
        ...rest,
        animate,
        className,
        custom,
        exit: "exit",
        initial: unmountOnExit ? "exit" : false,
        style: {
          overflow: "hidden",
          display: "block",
          ...style
        },
        variants
      }
    ) });
  }
);
CollapseTransition.displayName = "NextUI.CollapseTransition";
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  CollapseTransition
});
